
function MAKROTList.Get(Index: Integer): MAKROPointerType;
begin
  Result := MAKROPointerType(FList.Get(Index));
end;

procedure MAKROTList.Grow;
begin
  // Only for compatibility with Delphi. Not needed.
end;

procedure MAKROTList.Put(Index: Integer; Item: MAKROPointerType);
begin
  FList.Put(Index, Item);
end;

function MAKROTList.Extract(item: MAKROPointerType): MAKROPointerType;
begin
  Result := MAKROPointerType(FList.Extract(item));
  Notify(Result, lnExtracted);
end;

procedure MAKROTList.Notify(Ptr: MAKROPointerType; Action: TListNotification);
begin
end;

function MAKROTList.GetCapacity: integer;
begin
  Result := FList.Capacity;
end;

procedure MAKROTList.SetCapacity(NewCapacity: Integer);
begin
  FList.SetCapacity(NewCapacity);
end;

function MAKROTList.GetCount: Integer;
begin
  Result := FList.Count;
end;

procedure MAKROTList.SetCount(NewCount: Integer);
begin
  FList.SetCount(NewCount);
end;

constructor MAKROTList.Create;
begin
  inherited Create;
  FList := TFPMList.Create;
end;

destructor MAKROTList.Destroy;
begin
  If (Flist<>Nil) then
    Clear;
  FreeAndNil(FList);
  inherited Destroy;
end;

function MAKROTList.Add(Item: MAKROPointerType): Integer;
begin
  Result := FList.Add(Item);
  if Item <> nil then
    Notify(Item, lnAdded);
end;

procedure MAKROTList.Clear;

begin
  If Assigned(Flist) then
    While (FList.Count>0) do
      Delete(Count-1);
end;

procedure MAKROTList.Delete(Index: Integer);

var P : MAKROPointerType;

begin
  P:=MAKROPointerType(FList.Get(Index));
  FList.Delete(Index);
  if assigned(p) then Notify(p, lnDeleted);
end;

class procedure MAKROTList.Error(const Msg: string; Data: PtrInt);
begin
  Raise EListError.CreateFmt(Msg,[Data]) at get_caller_addr(get_frame);
end;

procedure MAKROTList.Exchange(Index1, Index2: Integer);
begin
  FList.Exchange(Index1, Index2);
end;

function MAKROTList.Expand: MAKROTList;
begin
  FList.Expand;
  Result:=Self;
end;

function MAKROTList.First: MAKROPointerType;
begin
  Result := MAKROPointerType(FList.First);
end;

function MAKROTList.IndexOf(Item: MAKROPointerType): Integer;
begin
  Result := FList.IndexOf(Item);
end;

procedure MAKROTList.Insert(Index: Integer; Item: MAKROPointerType);
begin
  FList.Insert(Index, Item);
  if Item <> nil then
    Notify(Item,lnAdded);
end;

function MAKROTList.Last: MAKROPointerType;
begin
  Result := MAKROPointerType(FList.Last);
end;

procedure MAKROTList.Move(CurIndex, NewIndex: Integer);
begin
  FList.Move(CurIndex, NewIndex);
end;

function MAKROTList.Remove(Item: MAKROPointerType): Integer;
begin
  Result := IndexOf(Item);
  If Result <> -1 then
    Self.Delete(Result);
end;

procedure MAKROTList.Pack;
begin
  FList.Pack;
end;

procedure MAKROTList.Sort(Compare: TListSortCompare);
begin
  FList.Sort(Compare);
end;

procedure MAKROTList.Assign(Obj:MAKROTList);
begin
  FList.Assign(Obj.FList);
end;

function MAKROTList.GetList: PPointerList;
begin
  Result := FList.List;
end;
